/**
 * Branch on GitHub.
 */
export class GithubBranch extends Branch {
    constructor(owner: any, name: any, options: any);
    /**
     * Writes content into the branch
     * {@link https://developer.github.com/v3/git/blobs/#get-a-blob}
     * @param {ContentEntry} entry
     * @return {Promise<ContentEntry>} written content with sha values set
     */
    writeEntry(entry: ContentEntry): Promise<ContentEntry>;
    /**
     * {@link https://developer.github.com/v3/git/trees/#create-a-tree}
     * {@link https://developer.github.com/v3/git/commits/#create-a-commit}
     * {@link https://developer.github.com/v3/git/refs/#update-a-reference}
     * @param {string} message
     * @param {ContentEntry[]} entries
     * @param {Object} [options]
     */
    commit(message: string, entries: ContentEntry[], options?: any): Promise<any>;
    /**
     * {@link https://developer.github.com/v3/repos/contents/#get-repository-content}
     * @param {string} name
     */
    entry(name: string): Promise<any>;
    /**
     *
     * @param {string[]|string} patterns
     * @return {AsyncGenerator<ContentEntry>} all matching entries in the branch
     */
    entries(patterns: string[] | string): AsyncGenerator<ContentEntry>;
    #private;
}
import { Branch } from "repository-provider";
import { ContentEntry } from "content-entry";
